==> citrus-ws-4.0.2-sources.jar: org/citrusframework/model/config/ws/WebServiceClientModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.ws;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="request-url" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="web-service-template" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-factory" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-sender" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="interceptor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="interceptors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-resolver" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="fault-strategy">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             <enumeration value="throwsException"/>
 *             <enumeration value="propagateError"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "client")
public class WebServiceClientModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "request-url", required = true)
    protected String requestUrl;
    @XmlAttribute(name = "web-service-template")
    protected String webServiceTemplate;
    @XmlAttribute(name = "message-factory")
    protected String messageFactory;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "message-sender")
    protected String messageSender;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;
    @XmlAttribute(name = "interceptor")
    protected String interceptor;
    @XmlAttribute(name = "interceptors")
    protected String interceptors;
    @XmlAttribute(name = "endpoint-resolver")
    protected String endpointResolver;
    @XmlAttribute(name = "fault-strategy")
    protected String faultStrategy;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der requestUrl-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestUrl() {
        return requestUrl;
    }

    /**
     * Legt den Wert der requestUrl-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestUrl(String value) {
        this.requestUrl = value;
    }

    /**
     * Ruft den Wert der webServiceTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWebServiceTemplate() {
        return webServiceTemplate;
    }

    /**
     * Legt den Wert der webServiceTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWebServiceTemplate(String value) {
        this.webServiceTemplate = value;
    }

    /**
     * Ruft den Wert der messageFactory-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageFactory() {
        return messageFactory;
    }

    /**
     * Legt den Wert der messageFactory-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageFactory(String value) {
        this.messageFactory = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der messageSender-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageSender() {
        return messageSender;
    }

    /**
     * Legt den Wert der messageSender-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageSender(String value) {
        this.messageSender = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

    /**
     * Ruft den Wert der interceptor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptor() {
        return interceptor;
    }

    /**
     * Legt den Wert der interceptor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptor(String value) {
        this.interceptor = value;
    }

    /**
     * Ruft den Wert der interceptors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptors() {
        return interceptors;
    }

    /**
     * Legt den Wert der interceptors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptors(String value) {
        this.interceptors = value;
    }

    /**
     * Ruft den Wert der endpointResolver-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointResolver() {
        return endpointResolver;
    }

    /**
     * Legt den Wert der endpointResolver-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointResolver(String value) {
        this.endpointResolver = value;
    }

    /**
     * Ruft den Wert der faultStrategy-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFaultStrategy() {
        return faultStrategy;
    }

    /**
     * Legt den Wert der faultStrategy-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFaultStrategy(String value) {
        this.faultStrategy = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

}

==> citrus-ws-4.5.2-sources.jar: org/citrusframework/model/config/ws/WebServiceClientModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.5 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.ws;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="request-url" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="web-service-template" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-factory" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-sender" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="interceptor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="interceptors" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-resolver" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="fault-strategy">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             <enumeration value="throwsException"/>
 *             <enumeration value="propagateError"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "client")
public class WebServiceClientModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "request-url", required = true)
    protected String requestUrl;
    @XmlAttribute(name = "web-service-template")
    protected String webServiceTemplate;
    @XmlAttribute(name = "message-factory")
    protected String messageFactory;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "message-sender")
    protected String messageSender;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;
    @XmlAttribute(name = "interceptor")
    protected String interceptor;
    @XmlAttribute(name = "interceptors")
    protected String interceptors;
    @XmlAttribute(name = "endpoint-resolver")
    protected String endpointResolver;
    @XmlAttribute(name = "fault-strategy")
    protected String faultStrategy;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der requestUrl-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRequestUrl() {
        return requestUrl;
    }

    /**
     * Legt den Wert der requestUrl-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRequestUrl(String value) {
        this.requestUrl = value;
    }

    /**
     * Ruft den Wert der webServiceTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWebServiceTemplate() {
        return webServiceTemplate;
    }

    /**
     * Legt den Wert der webServiceTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWebServiceTemplate(String value) {
        this.webServiceTemplate = value;
    }

    /**
     * Ruft den Wert der messageFactory-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageFactory() {
        return messageFactory;
    }

    /**
     * Legt den Wert der messageFactory-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageFactory(String value) {
        this.messageFactory = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der messageSender-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageSender() {
        return messageSender;
    }

    /**
     * Legt den Wert der messageSender-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageSender(String value) {
        this.messageSender = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

    /**
     * Ruft den Wert der interceptor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptor() {
        return interceptor;
    }

    /**
     * Legt den Wert der interceptor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptor(String value) {
        this.interceptor = value;
    }

    /**
     * Ruft den Wert der interceptors-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getInterceptors() {
        return interceptors;
    }

    /**
     * Legt den Wert der interceptors-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setInterceptors(String value) {
        this.interceptors = value;
    }

    /**
     * Ruft den Wert der endpointResolver-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointResolver() {
        return endpointResolver;
    }

    /**
     * Legt den Wert der endpointResolver-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointResolver(String value) {
        this.endpointResolver = value;
    }

    /**
     * Ruft den Wert der faultStrategy-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFaultStrategy() {
        return faultStrategy;
    }

    /**
     * Legt den Wert der faultStrategy-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFaultStrategy(String value) {
        this.faultStrategy = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

}
